@@ -34,9 +34,6 @@ APIS = {
 VIDEO_EXTENSIONS = [ext for ext in mimetypes.types_map if mimetypes.types_map[ext].split('/')[0] == 'video']
 IMG_EXTENSIONS = [ext for ext in mimetypes.types_map if mimetypes.types_map[ext].split('/')[0] == 'image']
 
-MONTH_ABREVIATION_INDEX = 0
-MONTH_FULLNAME_INDEX = 1
-
 ENGLISH_INDEX = 0
 DUTCH_INDEX = 1
 
